#!/bin/bash
#
# Copyright (c) 2012-2014 Fixpoint Inc. All rights reserved.
# ---
# Kompira簡易インストーラ：
#   - 1台構成版
#   - Apache/PostgreSQLを使用
#
# 動作要件：
#   - x86_64
#   - CentOS 6.x以上
#   - Python 2.6系
#
KOMPIRA_USER=kompira
KOMPIRA_VAR_DIR=/var/opt/kompira
KOMPIRA_LOG_DIR=/var/log/kompira
INSTALL_LOG=install.$$.log
THIS_DIR=`dirname \`readlink -f $0\``
VERSION=1.4.9
BRANCH=1.4

KOMPIRA_PACKAGE=Kompira
KOMPIRA_JOBMNGR_PACKAGE=Kompira-jobmngr
KOMPIRA_SENDEVT_PACKAGE=Kompira-sendevt

CHKCONFIG=/sbin/chkconfig

ARCH=x86_64
PYTHON="Python 2.6.*"

POSTGRES="postgresql-9.3"
PYTHON_CHECK_LOCALHOST='from socket import *; [socket(*res[:3]) and exit(0) for res in getaddrinfo("localhost", 0, 0, SOCK_STREAM)] or exit(1)'

#
# iptables の許可ポート
#
IPTABLES_ACCEPT_PORT="80 443 5672"

#
# yum リポジトリ制御に必要なパッケージ
#
PACKAGES_FOR_YUMCONF="yum-utils yum-plugin-priorities"

#
# kompira_sendev に必要なパッケージ
#
PACKAGES_FOR_SENDEVT="python-setuptools"

#
# kompira_jobmngrd に必要なパッケージ
#
PACKAGES_FOR_JOBMNGR="wget gcc python-devel"
PACKAGES_FOR_JOBMNGR_OPENWSMAN="openwsman-python"

#
# kompira サーバに必要なパッケージ
#
PACKAGES_FOR_KOMPIRA="httpd mod_wsgi mod_ssl mercurial make sudo upstart libffi-devel openssl-devel"
PACKAGES_FOR_KOMPIRA_RABBITMQ="rabbitmq-server"
PACKAGES_FOR_KOMPIRA_POSTGRESQL="postgresql93-server postgresql93-contrib postgresql93-devel"
PACKAGES_FOR_KOMPIRA_EXTRA="jq"

#
# ロケールの設定
#
CONFIG_LOCALE=true
LOCALE_LANG="ja_JP.UTF-8"
LOCALE_CLOCK_ZONE="Asia/Tokyo"
LOCALE_CLOCK_UTC="false"

HTTPS_MODE=false
FORCE_MODE=false
UPDATE_MODE=false
JOBMNGR_MODE=false
SENDEVT_MODE=false
PROXY_URL=
KOMPIRA_SERVER=localhost

show_options()
{
    echo "***     - HTTPS_MODE       = $HTTPS_MODE"
    echo "***     - FORCE_MODE       = $FORCE_MODE"
    echo "***     - UPDATE_MODE      = $UPDATE_MODE"
    echo "***     - JOBMNGR_MODE     = $JOBMNGR_MODE"
    echo "***     - SENDEVT_MODE     = $SENDEVT_MODE"
    echo "***     - PROXY_URL        = $PROXY_URL"
    echo "***     - KOMPIRA_SERVER   = $KOMPIRA_SERVER"
}
SHOW_OPTIONS=show_options
TMPFILE=".kompira.$$.tmp"
SETUP_TYPE="Kompira のインストール"

. $THIS_DIR/scripts/setup_utils.sh


check_environ()
{
    echo
    echo "*** インストール環境を確認します"
    echo

    local result
    result=`uname -i`
    case $result in
        $ARCH)
            echo "*** アーキテクチャを確認しました ($result)" ;;
        *)
            echo "*** x86_64 Linux で実行してください"
            exit_setup 1 ;;
    esac

    check_os

    result=`python -V 2>&1 >/dev/null`
    case $result in
        $PYTHON)
            echo "*** Python のバージョンを確認しました ($result)" ;;
        *)
            echo "*** Python 2.6 系が必要です"
            exit_setup 1 ;;
    esac

    # 旧バージョンの PostgreSQL チェック
    if rpm -q postgresql > /dev/null 2>&1
    then
        echo "*** 旧バージョンの postgresql がインストールされています"
        echo "*** postgreql をアンインストールしてから再度実行してください"
        exit_setup 1
    fi

    # localhost に対して正しいアドレス情報を返すことをチェック
    if ! python -c "$PYTHON_CHECK_LOCALHOST" > /dev/null 2>&1
    then
        echo "*** localhost のアドレス情報が不正です"
        echo "*** /etc/hosts に localhost が設定されていることを確認してください"
        exit_setup 1
    fi

    if [ -n $PROXY_URL ]
    then
        export http_proxy="$PROXY_URL"
        export https_proxy="$PROXY_URL"
        export HTTP_PROXY="$PROXY_URL"
        export HTTPS_PROXY="$PROXY_URL"
    fi

    # yum check-upate がキャッシュを参照しないようにクリアしておく
    yum clean all > /dev/null
    yum -q check-update > /dev/null
    if [ "$?" -eq 1 ]
    then
        echo "*** yum レポジトリに接続できません"
        echo "*** このサーバがインターネットに接続できることを確認してください"
        if [ -z PROXY_URL ]
        then
            echo "*** プロキシサーバ経由でインターネットに接続する環境の場合"
            echo "*** --proxy オプションでプロキシの URL を指定してください"
        else
            echo "*** --proxy オプションで URL が正しく指定されていることを確認してください"
        fi
        exit_setup 1
    fi
}

check_installed_version()
{
    if $JOBMNGR_MODE || $SENDEVT_MODE; then return 0; fi
    if ! $UPDATE_MODE; then return 0; fi

    echo
    echo "*** インストール済みの Kompira バージョンをチェックします"
    echo

    INSTALLED_VERSION=`pip show Kompira | grep -E '^Version:'`
    INSTALLED_VERSION="${INSTALLED_VERSION#Version: }"
    case $INSTALLED_VERSION in
        "")
            echo "*** Kompira がインストールされていません"
            echo "*** 新規モードでインストールしてください"
            exit_setup 1
            ;;
        1.4.[012]*)
            echo "*** Kompira 1.4.2 以前がインストールされているため、"
            echo "*** アップデートできません"
            echo "***     INSTALLED_VERSION=$INSTALLED_VERSION"
            echo "*** 一旦、Kompira 1.4.5.post5 にアップデートしてから、"
            echo "*** 再度、アップデートインストールを行うか、"
            echo "*** 新規モードでインストールしてください。"
            exit_setup 1
            ;;
        ${BRANCH}*)
            echo "*** Kompira のアップデートを開始します"
            echo "***     $INSTALLED_VERSION  --->  $VERSION"
            ;;
        *)
            echo "*** インストールされている Kompira のメジャーバージョンが異なるため、"
            echo "*** アップデートできません"
            echo "***     INSTALLED_VERSION=$INSTALLED_VERSION"
            echo "***"
            echo "*** 新規モードでインストールしてください"
            exit_setup 1
            ;;
    esac
}

configure_locale()
{
    echo
    echo "*** ロケールの設定を確認します"
    echo

    if [ "$LANG" == "$LOCALE_LANG" ]
    then
        echo "*** LANG の設定を確認しました ($LANG)"
    else
        echo "*** LANG の設定を変更します ($LANG -> $LOCALE_LANG)"
        LANG=$LOCALE_LANG
    fi

    if grep -F "LANG=\"$LOCALE_LANG\"" /etc/sysconfig/i18n > /dev/null
    then
        echo "*** /etc/sysconfig/i18n の設定を確認しました ($LOCALE_LANG)"
    else
        echo "*** /etc/sysconfig/i18n の設定を変更します ($LOCALE_LANG)"
        mv /etc/sysconfig/i18n /etc/sysconfig/i18n.bak
        echo "LANG=\"$LOCALE_LANG\"" > /etc/sysconfig/i18n
    fi

    if diff -q /usr/share/zoneinfo/$LOCALE_CLOCK_ZONE /etc/localtime > /dev/null
    then
        echo "*** /etc/localtime の設定を確認しました ($LOCALE_CLOCK_ZONE)"
    else
        echo "*** /etc/localtime の設定を変更します ($LOCALE_CLOCK_ZONE)"
        cp /usr/share/zoneinfo/$LOCALE_CLOCK_ZONE /etc/localtime
        service_restart crond
    fi

    if grep -F "ZONE=\"$LOCALE_CLOCK_ZONE\"" /etc/sysconfig/clock > /dev/null
    then
        echo "*** /etc/sysconfig/clock の設定を確認しました ($LOCALE_CLOCK_ZONE)"
    else
        echo "*** /etc/sysconfig/clock の設定を変更します ($LOCALE_CLOCK_ZONE)"
        mv /etc/sysconfig/clock /etc/sysconfig/clock.bak
        echo -e "ZONE=\"$LOCALE_CLOCK_ZONE\"\nUTC=$LOCALE_CLOCK_UTC" > /etc/sysconfig/clock
    fi
}

create_user()
{
    if $UPDATE_MODE; then return 0; fi

    if ! id $KOMPIRA_USER > /dev/null 2>&1
    then
        echo
        echo "*** kompira ユーザーを作成します"
        echo
        useradd -s /sbin/nologin $KOMPIRA_USER
    fi
}

install_repo_openwsman()
{
    install_repo_direct \
        "Openwsman" "Openwsman.repo" \
        "http://download.opensuse.org/repositories/Openwsman/CentOS_CentOS-6/Openwsman.repo"
}

install_repo_epel()
{
    install_repo_from_rpm \
        "epel-release-6" "epel-release*" \
        "https://dl.fedoraproject.org/pub/epel/6/x86_64/epel-release-6-.*.noarch.rpm"
}

install_repo_pgdg()
{
    # AWS の場合は amzn レポジトリを使用するので不要
    if [ $SYSTEM == "AWS" ]; then return 0; fi
    install_repo_from_rpm \
        "pgdg-redhat93" "pgdg-redhat*" \
        "https://yum.postgresql.org/9.3/redhat/rhel-6-x86_64/pgdg-redhat93-9.3-.*.noarch.rpm"
}

install_packages()
{
    echo
    echo "*** kompira_sendevt に必要なパッケージをインストールします"
    echo
    #
    # AWS の場合は easy_install はインストール済み
    #
    if [ $SYSTEM != "AWS" ]
    then
        yum_install $PACKAGES_FOR_SENDEVT
    fi
    easy_install pip==7.1.2

    if $SENDEVT_MODE; then return 0; fi

    echo
    echo "*** kompira_jobmngrd に必要なパッケージをインストールします"
    echo
    if [ $SYSTEM == "RHOS" ]
    then
        YUM_OPTION="--enablerepo=rhel-6-server-optional-rpms" yum_install $PACKAGES_FOR_YUMCONF
    else
        yum_install $PACKAGES_FOR_YUMCONF
    fi
    yum_install $PACKAGES_FOR_JOBMNGR
    install_repo_openwsman
    DESCRIPTION="Openwsman 関連のパッケージ" \
        yum_install $PACKAGES_FOR_JOBMNGR_OPENWSMAN

    if $JOBMNGR_MODE; then return 0; fi

    echo
    echo "*** kompira サーバに必要なパッケージをインストールします"
    echo
    yum_install $PACKAGES_FOR_KOMPIRA
    install_repo_epel
    install_repo_pgdg
    DESCRIPTION="RabbitMQ 関連のパッケージ" \
        yum_install $PACKAGES_FOR_KOMPIRA_RABBITMQ
    if [ $SYSTEM == "AWS" ]
    then
        DESCRIPTION="PostgreSQL 関連のパッケージ" \
            yum_install $PACKAGES_FOR_KOMPIRA_POSTGRESQL
        #
        # PGDATA と PGLOG のデフォルト値を CentOS に合わせる
        #
        cat > /etc/sysconfig/pgsql/$POSTGRES <<EOF
# Set defaults for configuration variables
PGDATA=$PG_DATADIR
PGLOG=$PG_BASEDIR/pgstartup.log
EOF
    else
        DESCRIPTION="PostgreSQL 関連のパッケージ" \
            yum_install $PACKAGES_FOR_KOMPIRA_POSTGRESQL
    fi
    DESCRIPTION="追加のパッケージ" \
        yum_install $PACKAGES_FOR_KOMPIRA_EXTRA
}

uninstall_kompira()
{
    echo
    echo "*** Kompira デーモンを停止します"
    echo
    stop kompirad
    echo
    echo "*** Kompira ジョブマネージャを停止します"
    echo
    stop kompira_jobmngrd
    echo
    echo "*** インストール済みの Kompira があればアンインストールします"
    echo
    pip_uninstall_if_installed $KOMPIRA_PACKAGE $KOMPIRA_JOBMNGR_PACKAGE $KOMPIRA_SENDEVT_PACKAGE
}

install_kompira()
{
    echo
    echo "*** Kompira をシステムにインストールします"
    echo
    # 依存パッケージ psycopg2 のインストールに pgsql コマンドディレクトリが必要
    PATH=`pgsql_cmddir`:$PATH easy_install -Z --script-dir=$KOMPIRA_HOME/bin $THIS_DIR/dist/Kompira-$VERSION-py2.6.egg
    exit_if_failed "$?" "Kompira のパッケージインストールに失敗しました"
}

install_kompira_jobmngr()
{
    echo
    echo "*** Kompira ジョブマネージャをインストールします"
    echo
    easy_install -Z --script-dir=$KOMPIRA_HOME/bin $THIS_DIR/dist/Kompira_jobmngr-$VERSION-py2.6.egg
    exit_if_failed "$?" "Kompira ジョブマネージャのパッケージインストールに失敗しました"
}

install_kompira_sendevt()
{
    echo
    echo "*** Kompira sendevt をインストールします"
    echo
    easy_install -Z --script-dir=$KOMPIRA_HOME/bin $THIS_DIR/dist/Kompira_sendevt-$VERSION-py2.6.egg
    exit_if_failed "$?" "Kompira sendevt のパッケージインストールに失敗しました"
}

setup_pgsql()
{
    if $UPDATE_MODE; then return 0; fi

    PGSQL_USER="postgres"
    PGSQL_DB="postgres"
    echo
    echo "*** PostgreSQL の設定を行います"
    echo
    service $POSTGRES initdb
    service_start $POSTGRES

    # 行頭が local で始まる行中の文字列 peer を trust に置換する
    sed -i.old -e "/^local/{s/peer/trust/}" $PG_DATADIR/pg_hba.conf
    $CHKCONFIG $POSTGRES on
    service_restart $POSTGRES

    echo
    echo "*** Kompira 用データベース kompira を削除します"
    echo
    if ! $FORCE_MODE && psql -U $PGSQL_USER -d kompira -c \\q
    then
        echo "!!! Kompira 用データベース kompira は既に存在します"
        inquire "削除しますか？ (yes/No)" "n"
        if [ $answer != "y" ]
        then
            exit_setup 1
        fi
    fi
    dropdb -U $PGSQL_USER --if-exists -e kompira

    echo
    echo "*** Kompira データベースから kompira ユーザを削除します"
    echo
    if ! $FORCE_MODE && psql -U kompira -d $PGSQL_DB -c \\q
    then
        echo "!!! Kompira 用データベースユーザ kompira は既に存在します"
        inquire "削除しますか？ (yes/No)" "n"
        if [ $answer != "y" ]
        then
            exit_setup 1
        fi
    fi
    dropuser -U $PGSQL_USER --if-exists -e kompira

    echo
    echo "*** Kompira データベースユーザを作成します"
    echo
    createuser -U $PGSQL_USER --createdb -e kompira
    exit_if_failed "$?" "Kompira データベースユーザの作成に失敗しました"

    echo
    echo "*** Kompira データベースを作成します"
    echo
    createdb -U kompira --encoding=utf8 -e kompira
    exit_if_failed "$?" "Kompira データベースの作成に失敗しました"
}

setup_apache()
{
    if $UPDATE_MODE
    then
        echo
        echo "*** Apache の再起動を行います"
        echo
        service_restart httpd
        return 0
    fi

    echo
    echo "*** Apache に Kompira の設定を追加します"
    echo
    cat > /etc/httpd/conf.d/kompira.conf <<EOF
WSGIScriptAlias / $KOMPIRA_HOME/bin/wsgi.py
WSGIPassAuthorization On
Alias /robots.txt /var/www/html/robots.txt
#Alias /favicon.ico /var/www/html/favicon.ico
Alias /.static/ $KOMPIRA_VAR_DIR/html/
Alias /.upload/ $KOMPIRA_VAR_DIR/upload/
EOF
    if $HTTPS_MODE
    then
        cat >> /etc/httpd/conf.d/kompira.conf <<EOF
RewriteEngine On
RewriteCond %{REMOTE_ADDR} !^127\.0\.0\.1\$
RewriteCond %{SERVER_PORT} !^443\$
RewriteRule ^/(.*)?\$ https://%{HTTP_HOST}/\$1 [L,R]
EOF
    fi

    echo
    echo "*** Apache の HTTPD_LANG 設定を日本語 ($LOCALE_LANG) に変更します"
    echo
    sed -re "s/^#?\s*HTTPD_LANG=.*/HTTPD_LANG=$LOCALE_LANG/" -i.old /etc/sysconfig/httpd

    echo
    echo "*** Apache の起動設定を行います"
    echo
    $CHKCONFIG httpd on
    service_restart httpd
}

setup_rabbitmq()
{
    if $UPDATE_MODE
    then
        echo
        echo "*** RabbitMQ の再起動を行います"
        echo
        service_restart rabbitmq-server
        return 0
    fi

    echo
    echo "*** RabbitMQ の起動設定を行います"
    echo
    $CHKCONFIG rabbitmq-server on
    service_restart rabbitmq-server
}

setup_linux()
{
    if $UPDATE_MODE; then return 0; fi

    echo
    echo "*** iptables の設定を行います"
    echo
    for port in $IPTABLES_ACCEPT_PORT
    do
        iptables -I INPUT -p tcp --dport $port -j ACCEPT
    done
    iptables-save > $TMPFILE
    cp -S .old -b $TMPFILE /etc/sysconfig/iptables

    if [ ! -f /etc/selinux/config ]
    then
        echo
        echo "*** SELinux の設定ファイルが見つかりません"
        echo
        return
    fi

    echo
    echo "*** SELinux の設定を無効にします"
    echo
    # setsebool -P httpd_can_network_connect on
    setenforce 0
    sed -i.old -e "/SELINUX=/c SELINUX=permissive" /etc/selinux/config
}

setup_kompira()
{
    if [ ! -d $KOMPIRA_LOG_DIR ]
    then
        echo
        echo "*** ログディレクトリを作成します"
        echo
        mkdir -p $KOMPIRA_LOG_DIR
        chmod go+w $KOMPIRA_LOG_DIR
    fi

    echo
    echo "*** init 用起動設定ファイルを一旦削除します"
    echo
    rm -f /etc/init/kompirad.conf
    rm -f /etc/init/kompira_jobmngrd.conf

    if ! $UPDATE_MODE
    then
	echo
	echo "*** Kompira ジョブマネージャ/イベント送信 の設定ファイルをコピーします"
	echo
        sed -e "s/<kompira-server>/$KOMPIRA_SERVER/" $THIS_DIR/config/kompira.conf > $TMPFILE
        cp -S .old -b $TMPFILE $KOMPIRA_HOME/kompira.conf
    fi

    if $JOBMNGR_MODE || $SENDEVT_MODE; then return 0; fi

    echo
    echo "*** Kompira の自動起動用設定ファイルをコピーします"
    echo
    cp $THIS_DIR/config/kompirad /etc/init.d/
    chmod +x /etc/init.d/kompirad
    $CHKCONFIG --add kompirad

    echo
    echo "*** Kompira 用データベースを初期化します"
    echo
    $KOMPIRA_HOME/bin/manage.py collectstatic --noinput
    if $UPDATE_MODE
    then
        $KOMPIRA_HOME/bin/manage.py syncdb --noinput
        #
	# 初回マイグレーションの場合は --fake 実行して初期化しておく
	#
        if $KOMPIRA_HOME/bin/manage.py migrate kompira.incident --list | grep '( ) 0001_initial'
        then
            $KOMPIRA_HOME/bin/manage.py migrate kompira.incident --fake 0001
        fi
        if $KOMPIRA_HOME/bin/manage.py migrate kompira.process --list | grep '( ) 0001_initial'
        then
            $KOMPIRA_HOME/bin/manage.py migrate kompira.process --fake 0001
        fi
        $KOMPIRA_HOME/bin/manage.py migrate
    else
        $KOMPIRA_HOME/bin/manage.py syncdb --noinput --migrate
        $KOMPIRA_HOME/bin/manage.py loaddata bootstrap_data.json
    fi

    echo
    echo "*** Kompira 用データを初期化します"
    echo
    $KOMPIRA_HOME/bin/manage.py import_data --overwrite $THIS_DIR/exported/types.dat $THIS_DIR/exported/startup.dat
    $KOMPIRA_HOME/bin/manage.py compile_jobflow

    echo
    echo "*** Kompira デーモンの起動設定を行います"
    echo
    sed -e "s|<KOMPIRA_HOME>|$KOMPIRA_HOME|" -e "s|<PROXY_ENV>|env http_proxy=$PROXY_URL\nenv https_proxy=$PROXY_URL\nenv HTTP_PROXY=$PROXY_URL\nenv HTTPS_PROXY=$PROXY_URL|" $THIS_DIR/config/kompirad.conf > $TMPFILE
    cp -S .old -b $TMPFILE /etc/init/kompirad.conf
    start kompirad

    if $UPDATE_MODE; then return 0; fi

    echo
    echo "*** Kompira のデータディレクトリを作成します"
    echo
    rm -rf $KOMPIRA_VAR_DIR/upload
    rm -rf $KOMPIRA_VAR_DIR/repository
    mkdir $KOMPIRA_VAR_DIR/upload
    mkdir $KOMPIRA_VAR_DIR/repository
    chmod 777 $KOMPIRA_VAR_DIR
    chmod 777 $KOMPIRA_VAR_DIR/upload
    chmod 777 $KOMPIRA_VAR_DIR/repository
}

setup_kompira_jobmngr()
{
    echo
    echo "*** Kompira ジョブマネージャの起動設定を行います"
    echo
    sed -e "s|<KOMPIRA_HOME>|$KOMPIRA_HOME|" $THIS_DIR/config/kompira_jobmngrd.conf >$TMPFILE
    cp -S .old -b $TMPFILE /etc/init/kompira_jobmngrd.conf
    start kompira_jobmngrd
}

usage_exit()
{
    cat <<EOF
Usage: `basename $0` [OPTIONS] <kompira-server>

  --force               Force install.
  --https               Use https access only.
  --update              Update to new version of Kompira without initializing
                        data.
  --proxy <proxy>       Specify a proxy in the form
                        [user:passwd@]proxy.server:port.
  --jobmngr             Install Kompira job manager package.
  --sendevt             Install Kompira send event package.
  --help                Show this message.

EOF
    exit 1
}

parse_options()
{
    SPECIFY_SERVER=false
    OPTIONS=`getopt -q -o '' -l https,force,update,proxy:,jobmngr,sendevt,help -- "$@"`
    [ $? != 0 ] && usage_exit
    eval set -- "$OPTIONS"
    while true
    do
        arg="$1"
        case "$arg" in
            --https) HTTPS_MODE=true ;;
            --force) FORCE_MODE=true ;;
            --update) UPDATE_MODE=true ;;
            --proxy) PROXY_URL="http://${2#http*://}" ; shift ;;
            --jobmngr) JOBMNGR_MODE=true; SPECIFY_SERVER=true ;;
            --sendevt) SENDEVT_MODE=true; SPECIFY_SERVER=true ;;
            --) shift; break ;; # 引数は無視
            *) usage_exit ;;
        esac
        shift
    done

    if $JOBMNGR_MODE && $SENDEVT_MODE
    then
        echo '--jobmngr and --sendevt options are exclusive.'
        echo
        exit 1
    fi

    if $SPECIFY_SERVER
    then
	if [ -z "$1" ]
	then
            echo 'must specify <kompira-server>'
            echo
            usage_exit
	fi
	KOMPIRA_SERVER="$1"
    else
        if [ -n "$1" ]
        then
            echo "unknown argument \"$1\""
            echo
            usage_exit
        fi
    fi
}

################################################################

set -o pipefail
parse_options "$@"
{
start_setup
check_root
check_environ
check_installed_version

if $CONFIG_LOCALE
then
    configure_locale
fi

install_packages
uninstall_kompira

if $SENDEVT_MODE
then
    install_kompira_sendevt
    setup_kompira
elif $JOBMNGR_MODE
then
    create_user
    install_kompira_jobmngr
    setup_kompira
    setup_kompira_jobmngr
else
    create_user
    install_kompira
    setup_pgsql
    setup_apache
    setup_rabbitmq
    setup_linux
    setup_kompira
    setup_kompira_jobmngr
fi

setup_completed
exit_setup 0
} 2>&1 | tee $INSTALL_LOG
